@@ -976,7 +976,9 @@ class Converters:
                         name=parameter["name"],
                         origin=parameter["origin"],
                         value=Converters.create_parameter_value_response(parameter["origin"], parameter["value"]),
-                        description=parameter["description"])
+                        description=parameter["description"],
+                        modified_by=parameter["modified_by"],
+                        last_modified=parameter["last_modified"])
                 )
         return parameters
 
@@ -988,7 +990,9 @@ class Converters:
                 name=data["name"],
                 origin=data["origin"],
                 value=Converters.create_parameter_value_response(data["origin"], data["value"]),
-                description=data["description"])
+                description=data["description"],
+                modified_by=data["modified_by"],
+                last_modified=data["last_modified"])
         return parameter
 
     @staticmethod
